import os as __os
try:
    import pandas as __pd
except:
    raise SystemExit("No package found")

__here = __os.path.abspath(__os.path.dirname(__file__))

GGPLAY = __pd.read_csv(__os.path.join(__here, "googleplaystore.csv"))
HOTELDATA = __pd.read_csv(__os.path.join(__here, "hotel_bookings.csv"))


# online data




import setuptools
import re
from collections import defaultdict

def get_extra_requires(path, add_all=True):
    with open(path) as fp:
        extra_deps = defaultdict(set)
        for k in fp:
            if k.strip() and not k.startswith('#'):
                tags = set()
                if ':' in k:
                    k, v = k.split(':')
                    tags.update(vv.strip() for vv in v.split(','))
                tags.add(re.split('[<=>]', k)[0])
                for t in tags:
                    extra_deps[t].add(k)

        # add tag `all` at the end
        if add_all:
            extra_deps['all'] = set(vv for v in extra_deps.values() for vv in v)

    return extra_deps

setuptools.setup(
    name="absdataset",
    extras_require=get_extra_requires("extra_requirements.txt"),
    package_data={"": ["pkg_data/*"]},
    exclude_package_data={
        "": ["tempCodeRunnerFile.py"],
    },
)